#!/usr/bin/perl
# glob_opendir.pl
use v5.10;
use Benchmark;
use Cwd qw(cwd);

my( $files, $iterations ) = @ARGV;

$files      //=  1000;
$iterations //= 10000;

use File::Temp qw(tempdir);
my $dir = tempdir( CLEANUP => 1 );

my $original_cwd = cwd(); # save our current directory
chdir( $dir ) or die "Could not change to $dir: $!";
foreach ( 1 .. $files ) {
    open my($fh), '>', "$0.$_.tmp" or die "Could not create a file: $!";
    print { $fh } time();
    }

my $count = () = glob( '*' );
printf "$dir has %d files\n", $count;

timethese( $iterations, {
    'Opendir'  => q{ opendir my $dh, "."; my @f = readdir( $dh ) },
    'Glob'     => q{ my @f = glob(".* *") },
    }
    );

chdir( $original_cwd );